<?php
require __DIR__.'/../datos/Conexion.clase.php';

class Persona extends Conexion {
    public function buscarQR($codigo_qr_encoded){
        try{
            $codigoQrDecoded = base64_decode($codigo_qr_encoded);
            $separador = explode("#", $codigoQrDecoded);
            //codigo_busqueda puede ser el codigo de conductor o de vehiculo, dependiendo del caso
            $codigo_busqueda = explode("=", $separador[0]);

            $sql = "SELECT
                        (case dt.estado when 'A' then 'ACTIVO' else 'INACTIVO' end) as estado,
                        ve.placa,
                        ve.marca,
                        ve.modelo,
                        to_char(ve.fecha_soat_vencimiento,'DD/MM/YYYY') as venc_soat,
                        to_char(ve.fecha_revision_vencimiento,'DD/MM/YYYY') as ven_rev,
                        tv.descripcion_tipo_vehiculo as tip_ve,
                        c.dni_conductor as dni,
                        (case (c.apellidos_paternos_conductor || ' ' || c.apellidos_maternos_conductor || ', ' || c.nombre_conductor) when ' , ' then 'NOMBRE NO REGISTRADO' else (c.apellidos_paternos_conductor || ' ' || c.apellidos_maternos_conductor || ', ' || c.nombre_conductor) end) as nombre_conductor,
                        c.nacionalidad,
                        (case coalesce(c.numero_licencia, 'NO REGISTRADA') when '' then 'NO REGISTRADA' else coalesce(c.numero_licencia, 'NO REGISTRADA') end) as licencia,
                        (case when coalesce(c.fecha_vencimiento_licencia, current_date) <= current_date then 'VENCIDA' else to_char(c.fecha_vencimiento_licencia, 'DD/MM/YYYY') end) as licencia_venc,
                        tp.descripcion_tipo_personal as tip_pe
                    FROM
                        detalle_transporte as dt inner join vehiculo as ve on(dt.codigo_vehiculo = ve.codigo_vehiculo)
                        inner join conductor_control as c on(dt.codigo_conductor = c.codigo_conductor)
                        inner join tipo_vehiculo_control as tv on(ve.codigo_tipo_vehiculo = tv.codigo_tipo_vehiculo)
                        inner join categoria_personal_fundo as tp on(c.codigo_tipo_personal = tp.codigo_categoria_personal)
                    WHERE ";
            if (strstr($codigoQrDecoded, 'cod_cond')) {
                $sql .= " dt.codigo_conductor = :p_codigo_busqueda ";
            }else{
                $sql .= " dt.codigo_vehiculo = :p_codigo_busqueda ";
            }
            $sql .= " ORDER BY dt.fecha_registro desc;";
            $sentencia = $this->dblink->prepare($sql);
            $sentencia->bindParam(":p_codigo_busqueda", $codigo_busqueda[1]);
            $sentencia->execute();
            $resultado = $sentencia->fetch(PDO::FETCH_ASSOC);
            if(!$sentencia->rowCount()){
                $resultado = [];
            }
            return $resultado;
        }catch(Exception $e){
            throw $e;
        }
    }

    public function listarPersonas(){
        try {
            $sql = "SELECT DISTINCT
                        trim(coalesce(cond.dni_conductor, '0')) as dni,
                        trim(coalesce(cond.nombre_conductor, '0')) as nombre,
                        trim(coalesce(cond.apellidos_paternos_conductor, '0')) as paterno,
                        trim(coalesce(cond.apellidos_maternos_conductor, '0')) as materno,
                        trim(coalesce(cond.estado_conductor, 'A')) as estado
                    FROM
                        conductor_control as cond
                    ORDER BY
                            3,4,1 asc";
            $sentencia = $this->dblink->prepare($sql);
            $sentencia->execute();
            if (!$sentencia->rowCount()) {
                return [];
            }
            $resultado = $sentencia->fetchAll(PDO::FETCH_ASSOC);
            return $resultado;
        } catch (Exception $e) {
            throw $e;
        }
    }

    public function listarSancionados(){
        try {
            $sql = "SELECT
                        trim(cond.dni_conductor) as dni,
                        trim(coalesce(san.motivo,'--')) as motivo,
                        to_char(san.fecha_desde,'DD-MM-YYYY') AS desde,
                        to_char(san.fecha_hasta,'DD-MM-YYYY') AS hasta
                    FROM
                        sancion_conductor as san inner join conductor_control as cond on(san.codigo_conductor = cond.codigo_conductor);";
            $sentencia = $this->dblink->prepare($sql);
            $sentencia->execute();

            if (!$sentencia->rowCount()) {
                throw new Exception("No hay datos de sancionados disponibles.");
            }

            $resultado = $sentencia->fetchAll(PDO::FETCH_ASSOC);

            return $resultado;
        } catch (Exception $e) {
            throw $e;
        }
    }
}